<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" />
	<xsl:param name="param" />

	<xsl:template match="/config" xmlns:xrl="http://1060.org/xrl">
		<div>
			<form method="post">
			<table class="data-table" style="border-spacing: 0px;">
				
				<tr class="vis-title"><td colspan="3">Kernel Settings</td></tr>
				<xsl:call-template name="item">
					<xsl:with-param name="label">Thread Pool</xsl:with-param>
					<xsl:with-param name="data">netkernel.scheduler.threadcount</xsl:with-param>
					<xsl:with-param name="comment">Number of worker threads held to handle asynchronous requests.</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="item">
					<xsl:with-param name="label">Shutdown Grace</xsl:with-param>
					<xsl:with-param name="data">netkernel.scheduler.thread.timeout</xsl:with-param>
					<xsl:with-param name="comment">Grace period for requests to complete during shutdown or restart.</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="item">
					<xsl:with-param name="label">Max Request Depth</xsl:with-param>
					<xsl:with-param name="data">netkernel.scheduler.maxstackdepth</xsl:with-param>
					<xsl:with-param name="comment">Maximum allowed depth of subrequests before stack overflow</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="item">
					<xsl:with-param name="label">Max Java Stacktrace</xsl:with-param>
					<xsl:with-param name="data">netkernel.exception.javastack</xsl:with-param>
					<xsl:with-param name="comment">Maximum captured stack depth of Java exceptions.</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="item">
					<xsl:with-param name="label">Filesystem Poll</xsl:with-param>
					<xsl:with-param name="data">netkernel.poll</xsl:with-param>
					<xsl:with-param name="comment">Millisecond period to poll filesystem resources for changes.</xsl:with-param>
				</xsl:call-template>
				
				<xsl:call-template name="item">
					<xsl:with-param name="label">Runlevel</xsl:with-param>
					<xsl:with-param name="data">netkernel.init.runlevel</xsl:with-param>
					<xsl:with-param name="comment">Determines which modules are loaded</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="item">
					<xsl:with-param name="label">Instance Id</xsl:with-param>
					<xsl:with-param name="data">netkernel.instance.identifier</xsl:with-param>
					<xsl:with-param name="comment">Identifier string for this instance.</xsl:with-param>
				</xsl:call-template>

				<tr>
					<td class="label">Debug:</td>
					<td>
						<input type="checkbox" name="netkernel.debug" >
							<xsl:if test="item[name='netkernel.debug']/value='true'">
								<xsl:attribute name="checked">true</xsl:attribute>
							</xsl:if>
						</input>
					</td>
					<td>
						<div style="font-size: 80%; font-style: italic;">
							Enable development time debug with associated overhead.
						</div>
					</td>
				</tr>
				
				<tr class="vis-title"><td colspan="3">Data Collection</td></tr>
				
				<xsl:call-template name="item">
					<xsl:with-param name="label">Statistics Period</xsl:with-param>
					<xsl:with-param name="data">netkernel.statistics.period</xsl:with-param>
					<xsl:with-param name="comment">Millisecond period to collect kernel statistics</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="item">
					<xsl:with-param name="label">Statistics Window</xsl:with-param>
					<xsl:with-param name="data">netkernel.statistics.window</xsl:with-param>
					<xsl:with-param name="comment">Number of statistics samples kept</xsl:with-param>
				</xsl:call-template>
				
				<tr class="vis-title"><td colspan="3">Cache Configuration</td></tr>

				<xsl:call-template name="item">
					<xsl:with-param name="label">Heap Headroom</xsl:with-param>
					<xsl:with-param name="data">se.concurrentcache.headroomMb</xsl:with-param>
					<xsl:with-param name="comment">Free Mb of heap reserved before representation cache is culled</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="item">
					<xsl:with-param name="label">Max Size</xsl:with-param>
					<xsl:with-param name="data">se.concurrentcache.maxsize</xsl:with-param>
					<xsl:with-param name="comment">Number of items in representation cache before it is culled</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="item">
					<xsl:with-param name="label">Cull percent</xsl:with-param>
					<xsl:with-param name="data">se.concurrentcache.cull%</xsl:with-param>
					<xsl:with-param name="comment">Percentage items of removed from representation cache in one cull</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="item">
					<xsl:with-param name="label">Resolution Cache</xsl:with-param>
					<xsl:with-param name="data">se.resolutioncache.size</xsl:with-param>
					<xsl:with-param name="comment">Number of items in resolution cache before it is culled</xsl:with-param>
				</xsl:call-template>

				<tr class="vis-title"><td colspan="3">Proxy Settings</td></tr>

				<xsl:call-template name="item">
					<xsl:with-param name="label">HTTP Proxy Host</xsl:with-param>
					<xsl:with-param name="data">http.proxyHost</xsl:with-param>
					<xsl:with-param name="comment">(reboot required)</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="item">
					<xsl:with-param name="label">HTTP Proxy Port</xsl:with-param>
					<xsl:with-param name="data">http.proxyPort</xsl:with-param>
					<xsl:with-param name="comment">(reboot required)</xsl:with-param>
				</xsl:call-template>

				<tr>
					<td><img src="/nkse/style/img/transparent.gif" height="64" width="1"/></td>
					<td style="vertical-align: middle; text-align: right;"><input type="submit" value="save settings" class="btn"/></td><td/>
				</tr>
				
			</table>
			</form>
		</div>
	</xsl:template>
	
	<xsl:template name="item">
		<xsl:param name="label"/>
		<xsl:param name="data"/>
		<xsl:param name="comment"/>
		
		<tr>
			<xsl:if test="item[name=$data]/error">
				<xsl:attribute name="class">error</xsl:attribute>
			</xsl:if>
			<td class="label"><xsl:value-of select="$label"/>:</td>
			<td><input type="text" name="{$data}" value="{item[name=$data]/value}"/></td>
			<td>
				<xsl:choose>
					<xsl:when test="item[name=$data]/error">
						<xsl:value-of select="item[name=$data]/error"/>
					</xsl:when>
					<xsl:otherwise>
						<div style="font-size: 80%; font-style: italic;"><xsl:value-of select="$comment"/></div>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
		
	</xsl:template>

</xsl:stylesheet> 
